@@ -691,8 +691,9 @@ liq_error liq_invalid_result (liq_result * result)
 liq_error liq_set_quality(liq_attr* attr, int minimum, int target)
 {
     CHECK_STRUCT_TYPE(attr, liq_attr);
-    if (target < 0 || target > 100 || target < minimum || minimum < 0) return LIQ_VALUE_OUT_OF_RANGE;
-
+    if (target < 0 || target > 100 || target < minimum || minimum < 0) {
+	return LIQ_VALUE_OUT_OF_RANGE;
+    }
     attr->target_mse = quality_to_mse(target);
     attr->max_mse = quality_to_mse(minimum);
     return LIQ_OK;
@@ -701,9 +702,12 @@ liq_error liq_set_quality(liq_attr* attr, int minimum, int target)
 liq_error liq_get_quality(liq_attr *attr, int *minimum, int *target)
 {
     CHECK_STRUCT_TYPE(attr, liq_attr);
-    if (!CHECK_USER_POINTER(minimum)) return LIQ_INVALID_POINTER;
-    if (!CHECK_USER_POINTER(target)) return LIQ_INVALID_POINTER;
-
+    if (!CHECK_USER_POINTER(minimum)) {
+	return LIQ_INVALID_POINTER;
+    }
+    if (!CHECK_USER_POINTER(target)) {
+	return LIQ_INVALID_POINTER;
+    }
     *minimum = mse_to_quality(attr->max_mse);
     *target = mse_to_quality(attr->target_mse);
     return LIQ_OK;
@@ -751,7 +755,8 @@ liq_error liq_set_speed(liq_attr* attr, int speed)
     if (speed < 1 || speed > 10) {
 	return LIQ_VALUE_OUT_OF_RANGE;
     }
-    int iterations = MAX(8-speed,0); iterations += iterations * iterations/2;
+    int iterations = MAX(8-speed,0);
+    iterations += iterations * iterations/2;
     attr->voronoi_iterations = iterations;
     attr->voronoi_iteration_limit = 1.0/(double)(1<<(23-speed));
     attr->feedback_loop_trials = MAX(56-9*speed, 0);
@@ -776,9 +781,12 @@ static liq_error liq_remapping_result_destroy(liq_remapping_result *result)
 {
     CHECK_STRUCT_TYPE(result, liq_remapping_result);
 
-    if (result->palette) pam_freecolormap(result->palette);
-    if (result->pixels) result->free(result->pixels);
-
+    if (result->palette) {
+	pam_freecolormap(result->palette);
+    }
+    if (result->pixels) {
+	result->free(result->pixels);
+    }
     result->magic_header = liq_freed_magic;
     result->free(result);
     return LIQ_OK;
@@ -844,23 +852,6 @@ liq_error liq_set_log_flush_callback(liq_attr *attr, liq_log_flush_callback_func
     return LIQ_OK;
 }
 
-liq_attr* liq_attr_create()
-{
-    return liq_attr_create_with_allocator(NULL, NULL);
-}
-
-liq_error
-liq_attr_destroy(liq_attr *attr)
-{
-    CHECK_STRUCT_TYPE(attr, liq_attr);
-
-    liq_verbose_printf_flush(attr);
-
-    attr->magic_header = liq_freed_magic;
-    attr->free(attr);
-    return LIQ_OK;
-}
-
 static void *liq_aligned_malloc(size_t size)
 {
     unsigned char *ptr = malloc(size + 16);
@@ -886,14 +877,21 @@ static void liq_aligned_free(void *inptr)
 liq_attr* liq_attr_create_with_allocator(void* (*custom_malloc)(size_t), void (*custom_free)(void*))
 {
     if (!custom_malloc && !custom_free) {
+        custom_malloc = malloc;
+        custom_free = free;
+	/*
         custom_malloc = liq_aligned_malloc;
         custom_free = liq_aligned_free;
-    } else if (!custom_malloc != !custom_free) {
+	*/
+    }
+    else if (!custom_malloc != !custom_free) {
         return NULL; // either specify both or none
     }
 
     liq_attr *attr = custom_malloc(sizeof(liq_attr));
-    if (!attr) return NULL;
+    if (!attr) {
+	return NULL;
+    }
     *attr = (liq_attr) {
         .magic_header = liq_attr_magic,
         .malloc = custom_malloc,
@@ -908,6 +906,23 @@ liq_attr* liq_attr_create_with_allocator(void* (*custom_malloc)(size_t), void (*
     return attr;
 }
 
+liq_attr* liq_attr_create()
+{
+    return liq_attr_create_with_allocator (NULL, NULL);
+}
+
+liq_error
+liq_attr_destroy(liq_attr *attr)
+{
+    CHECK_STRUCT_TYPE(attr, liq_attr);
+
+    liq_verbose_printf_flush(attr);
+
+    attr->magic_header = liq_freed_magic;
+    attr->free(attr);
+    return LIQ_OK;
+}
+
 static liq_error liq_image_create_internal_2 (liq_attr *attr, rgba_pixel* rows[], liq_image_get_rgba_row_callback *row_callback, void *row_callback_user_info, int width, int height, double gamma, liq_image ** image_ptr)
 {
     CHECK_STRUCT_TYPE(attr, liq_attr);
